@@ -42,5 +42,10 @@ icons here</source>
         <source>Remove from quicklaunch</source>
         <translation>Уклони са брзог покретања</translation>
     </message>
+    <message>
+        <location filename="../quicklaunchbutton.cpp" line="72"/>
+        <source>Refresh</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
