@@ -35,7 +35,8 @@
 
 LXQtVolumeConfiguration::LXQtVolumeConfiguration(PluginSettings *settings, bool ossAvailable, QWidget *parent) :
     LXQtPanelPluginConfigDialog(settings, parent),
-    ui(new Ui::LXQtVolumeConfiguration)
+    ui(new Ui::LXQtVolumeConfiguration),
+    mLockSettingChanges(false)
 {
     ui->setupUi(this);
 
@@ -50,10 +51,6 @@ LXQtVolumeConfiguration::LXQtVolumeConfiguration(PluginSettings *settings, bool
     connect(ui->allwaysShowNotificationsCheckBox,  &QAbstractButton::toggled,                           this, &LXQtVolumeConfiguration::allwaysShowNotificationsCheckBoxChanged);
     connect(ui->showKeyboardNotificationsCheckBox, &QAbstractButton::toggled,                           this, &LXQtVolumeConfiguration::showKeyboardNotificationsCheckBoxChanged);
 
-    // currently, this option is only supported by the pulse audio backend
-    if(!ui->pulseAudioRadioButton->isChecked())
-        ui->ignoreMaxVolumeCheckBox->setEnabled(false);
-
     if (ossAvailable)
         connect(ui->ossRadioButton, &QRadioButton::toggled, this, &LXQtVolumeConfiguration::audioEngineChanged);
     else
@@ -100,66 +97,80 @@ void LXQtVolumeConfiguration::audioEngineChanged(bool checked)
     bool canIgnoreMaxVolume = false;
     if (ui->pulseAudioRadioButton->isChecked())
     {
-        settings().setValue(QStringLiteral(SETTINGS_AUDIO_ENGINE), QStringLiteral("PulseAudio"));
+        if (!mLockSettingChanges)
+            settings().setValue(QStringLiteral(SETTINGS_AUDIO_ENGINE), QStringLiteral("PulseAudio"));
         canIgnoreMaxVolume = true;
     }
-    else if(ui->alsaRadioButton->isChecked())
-        settings().setValue(QStringLiteral(SETTINGS_AUDIO_ENGINE), QStringLiteral("Alsa"));
-    else
-        settings().setValue(QStringLiteral(SETTINGS_AUDIO_ENGINE), QStringLiteral("Oss"));
+    else if (!mLockSettingChanges)
+    {
+        if(ui->alsaRadioButton->isChecked())
+            settings().setValue(QStringLiteral(SETTINGS_AUDIO_ENGINE), QStringLiteral("Alsa"));
+        else
+            settings().setValue(QStringLiteral(SETTINGS_AUDIO_ENGINE), QStringLiteral("Oss"));
+    }
     ui->ignoreMaxVolumeCheckBox->setEnabled(canIgnoreMaxVolume);
 }
 
 void LXQtVolumeConfiguration::sinkSelectionChanged(int index)
 {
-    settings().setValue(QStringLiteral(SETTINGS_DEVICE), index >= 0 ? index : 0);
+    if (!mLockSettingChanges)
+        settings().setValue(QStringLiteral(SETTINGS_DEVICE), index >= 0 ? index : 0);
 }
 
 void LXQtVolumeConfiguration::showOnClickedChanged(bool state)
 {
-    settings().setValue(QStringLiteral(SETTINGS_SHOW_ON_LEFTCLICK), state);
+    if (!mLockSettingChanges)
+        settings().setValue(QStringLiteral(SETTINGS_SHOW_ON_LEFTCLICK), state);
 }
 
 void LXQtVolumeConfiguration::muteOnMiddleClickChanged(bool state)
 {
-    settings().setValue(QStringLiteral(SETTINGS_MUTE_ON_MIDDLECLICK), state);
+    if (!mLockSettingChanges)
+        settings().setValue(QStringLiteral(SETTINGS_MUTE_ON_MIDDLECLICK), state);
 }
 
 void LXQtVolumeConfiguration::mixerLineEditChanged(const QString &command)
 {
-    settings().setValue(QStringLiteral(SETTINGS_MIXER_COMMAND), command);
+    if (!mLockSettingChanges)
+        settings().setValue(QStringLiteral(SETTINGS_MIXER_COMMAND), command);
 }
 
 void LXQtVolumeConfiguration::stepSpinBoxChanged(int step)
 {
-    settings().setValue(QStringLiteral(SETTINGS_STEP), step);
+    if (!mLockSettingChanges)
+        settings().setValue(QStringLiteral(SETTINGS_STEP), step);
 }
 
 void LXQtVolumeConfiguration::ignoreMaxVolumeCheckBoxChanged(bool state)
 {
-    settings().setValue(QStringLiteral(SETTINGS_IGNORE_MAX_VOLUME), state);
+    if (!mLockSettingChanges)
+        settings().setValue(QStringLiteral(SETTINGS_IGNORE_MAX_VOLUME), state);
 }
 
 void LXQtVolumeConfiguration::allwaysShowNotificationsCheckBoxChanged(bool state)
 {
-    settings().setValue(QStringLiteral(SETTINGS_ALLWAYS_SHOW_NOTIFICATIONS), state);
+    if (!mLockSettingChanges)
+        settings().setValue(QStringLiteral(SETTINGS_ALLWAYS_SHOW_NOTIFICATIONS), state);
     // since always showing notifications is the sufficient condition for showing them with keyboard,
     // self-consistency requires setting the latter to true whenever the former is toggled by the user
     ui->showKeyboardNotificationsCheckBox->setEnabled(!state);
     if (!ui->showKeyboardNotificationsCheckBox->isChecked())
         ui->showKeyboardNotificationsCheckBox->setChecked(true);
-    else
+    else if (!mLockSettingChanges)
         settings().setValue(QStringLiteral(SETTINGS_SHOW_KEYBOARD_NOTIFICATIONS), true);
 }
 
 void LXQtVolumeConfiguration::showKeyboardNotificationsCheckBoxChanged(bool state)
 {
-    settings().setValue(QStringLiteral(SETTINGS_SHOW_KEYBOARD_NOTIFICATIONS), state);
+    if (!mLockSettingChanges)
+        settings().setValue(QStringLiteral(SETTINGS_SHOW_KEYBOARD_NOTIFICATIONS), state);
 }
 
 
 void LXQtVolumeConfiguration::loadSettings()
 {
+    mLockSettingChanges = true;
+
     QString engine = settings().value(QStringLiteral(SETTINGS_AUDIO_ENGINE), QStringLiteral(SETTINGS_DEFAULT_AUDIO_ENGINE)).toString().toLower();
     if (engine == QLatin1String("pulseaudio"))
         ui->pulseAudioRadioButton->setChecked(true);
@@ -168,6 +179,10 @@ void LXQtVolumeConfiguration::loadSettings()
     else
         ui->ossRadioButton->setChecked(true);
 
+    // currently, this option is only supported by the pulse audio backend
+    if(!ui->pulseAudioRadioButton->isChecked())
+        ui->ignoreMaxVolumeCheckBox->setEnabled(false);
+
     setComboboxIndexByData(ui->devAddedCombo, settings().value(QStringLiteral(SETTINGS_DEVICE), SETTINGS_DEFAULT_DEVICE), 1);
     ui->showOnClickCheckBox->setChecked(settings().value(QStringLiteral(SETTINGS_SHOW_ON_LEFTCLICK), SETTINGS_DEFAULT_SHOW_ON_LEFTCLICK).toBool());
     ui->muteOnMiddleClickCheckBox->setChecked(settings().value(QStringLiteral(SETTINGS_MUTE_ON_MIDDLECLICK), SETTINGS_DEFAULT_MUTE_ON_MIDDLECLICK).toBool());
@@ -185,5 +200,7 @@ void LXQtVolumeConfiguration::loadSettings()
     {
         ui->showKeyboardNotificationsCheckBox->setChecked(settings().value(QStringLiteral(SETTINGS_SHOW_KEYBOARD_NOTIFICATIONS), SETTINGS_DEFAULT_SHOW_KEYBOARD_NOTIFICATIONS).toBool());
     }
+
+    mLockSettingChanges = false;
 }
 
